@@ -35,11 +35,15 @@ class MaterialOptimizer : public Processor
     virtual ~MaterialOptimizer();
 
     virtual bool process();
+    void setResetMaterials(bool r)  { mReset = r; }
 
 
   protected:
     float materialDifference(Material* m1, Material* m2);
     void mergeMaterials(Material* merge, Material* valid);
+    void resetMaterials();
+
+    bool mReset;
 };
 
 
