@@ -56,7 +56,7 @@
 #include "boufo/boufodebugwidget.h"
 #include "boufo/boufofactory.h"
 #include "bodebug.h"
-#include "optionsdialog.h"
+#include "optionsdialog/optionsdialog.h"
 #include "gameengine/bosongameengine.h"
 #include "gameengine/bosoncomputerio.h"
 #include "gameengine/speciestheme.h"
@@ -256,37 +256,44 @@ void BosonMainWidget::initializeGL()
  glHint(GL_CLIP_VOLUME_CLIPPING_HINT_EXT, GL_FASTEST);
 #endif
 
- boglInit();
+ BoGL::bogl()->initialize();
 
  d->mFPSCounter->reset();
 
  if (!context()->deviceIsPixmap()) {
-	boDebug() << k_funcinfo << "starting timer" << endl;
 	// start rendering (will also start the timer if necessary)
 	QTimer::singleShot(d->mUpdateInterval, this, SLOT(slotUpdateGL()));
 
 	// update system information (initializeGL() must have been called before
 	// this makes sense)
+	boProfiling->push("Update BoInfo");
 	BoInfo::boInfo()->update(this);
+	boProfiling->pop();
  }
 
+ boProfiling->push("init texture manager");
  BoTextureManager::initStatic();
- boTextureManager->initOpenGL();
+ boProfiling->pop();
 
  connect(kapp->eventLoop(), SIGNAL(signalUpdateGL()), this, SLOT(slotUpdateGL()));
 
- initUfoGUI();
-
  recursive = false;
  boDebug() << k_funcinfo << "done" << endl;
 }
 
 void BosonMainWidget::initUfoGUI()
 {
- boDebug() << k_funcinfo << endl;
+ static bool initialized = false;
+ if (initialized) {
+	return;
+ }
+ initialized = true;
+ PROFILE_METHOD
  glPushAttrib(GL_ALL_ATTRIB_BITS);
 
+ boProfiling->push("initUfo()");
  initUfo();
+ boProfiling->pop();
 
  BoUfoActionCollection::initActionCollection(ufoManager());
  ufoManager()->actionCollection()->setAccelWidget(this);
@@ -344,9 +351,12 @@ void BosonMainWidget::initUfoGUI()
 		this, SLOT(slotSetWidgetCursor(BosonCursor*)));
  d->mGameView->setGameFPSCounter(new BosonGameFPSCounter(d->mFPSCounter));
  d->mGameView->hide();
-
+ boProfiling->push("adding startup widget to widget stack");
  d->mWidgetStack->addWidget(d->mStartup);
+ boProfiling->pop();
+ boProfiling->push("adding gameview to widget stack");
  d->mWidgetStack->addWidget(d->mGameView);
+ boProfiling->pop();
  d->mWidgetStack->insertStackWidget(d->mStartup);
  d->mWidgetStack->insertStackWidget(d->mGameView);
 
@@ -354,12 +364,11 @@ void BosonMainWidget::initUfoGUI()
 
  d->mGameView->setMouseEventsEnabled(true, true);
 
- boDebug() << k_funcinfo << "creating BoUfoAction GUI" << endl;
+ boProfiling->push("createGUI()");
  ufoManager()->actionCollection()->createGUI();
- boDebug() << k_funcinfo << "creating BoUfoAction GUI done" << endl;
+ boProfiling->pop();
 
  glPopAttrib();
- boDebug() << k_funcinfo << "done" << endl;
 }
 
 void BosonMainWidget::setGameEngine(BosonGameEngine* gameEngine)
@@ -493,7 +502,6 @@ void BosonMainWidget::renderUfo()
 
 void BosonMainWidget::slotSetUpdateInterval(unsigned int ms)
 {
- boDebug() << k_funcinfo << ms << endl;
  d->mUpdateInterval = ms;
  QTimer::singleShot(d->mUpdateInterval, this, SLOT(slotUpdateGL()));
 }
