@@ -44,8 +44,6 @@
 
 #define FIX_EDGES 1
 
-static int g_cellsVisibleCalls = 0;
-
 
 BoGroundRendererQuadTreeNode* BoGroundRendererQuadTreeNode::createTree(unsigned int w, unsigned int h)
 {
@@ -380,10 +378,8 @@ void CellListBuilderTree::updateMapCache(const BosonMap* map)
 {
  if (mMap != map) {
 	mMap = 0;
-	boDebug() << k_funcinfo << "recreating map tree" << endl;
 	BosonProfiler prof("mapTreeGeneration");
 	recreateTree(map);
-	boDebug() << k_funcinfo << "recreating map tree done" << endl;
  }
  mMap = map;
 }
@@ -416,9 +412,7 @@ if (list) {
 	}
  }
 
- g_cellsVisibleCalls = 0;
  addVisibleCells(renderCells, mRoot);
-// boDebug() << k_funcinfo << g_cellsVisibleCalls << " calls - will render cells: " << mCount << endl;
 
  *renderCellsCount = mCount;
 // mMap = 0;
@@ -491,7 +485,6 @@ void CellListBuilderTree::addCells(int* cells, const BoGroundRendererQuadTreeNod
 
 bool CellListBuilderTree::cellsVisible(const BoGroundRendererQuadTreeNode* node, bool* partially)
 {
- g_cellsVisibleCalls++;
  if (!node) {
 	*partially = false;
 	return false;
@@ -773,7 +766,6 @@ void FogTexture::initFogTexture(const BosonMap* map)
 	mLastMap = map;
 	int w = BoTexture::nextPower2(mLastMapWidth + 2);
 	int h = BoTexture::nextPower2(mLastMapHeight + 2);
-	boDebug() << "FOGTEX: " << k_funcinfo << "w: " << w << "; h: " << h  << endl;
 	mFogTextureDataW = w;
 	mFogTextureDataH = h;
 	mFogTextureData = new unsigned char[w * h * 4];
@@ -788,9 +780,13 @@ void FogTexture::initFogTexture(const BosonMap* map)
 	for (unsigned int y = 1; y <= mLastMapHeight; y++) {
 		for (unsigned int x = 1; x <= mLastMapWidth; x++) {
 			unsigned char value = 0;
-			if (!localPlayerIO()->isFogged(x - 1, y - 1)) {
-				if (!mSmoothEdges || (x > 1 && y > 1 && x < mLastMapWidth && y < mLastMapHeight)) {
-					value = 255;
+			if (!mSmoothEdges || (x > 1 && y > 1 && x < mLastMapWidth && y < mLastMapHeight)) {
+				if (localPlayerIO()->isExplored(x - 1, y - 1)) {
+					if (localPlayerIO()->isFogged(x - 1, y - 1)) {
+						value = 205;
+					} else {
+						value = 255;
+					}
 				}
 			}
 			mFogTextureData[(y * w + x) * 4 + 0] = value;
@@ -879,7 +875,11 @@ void FogTexture::cellChanged(int x1, int y1, int x2, int y2)
  for (int y = y1; y <= y2; y++) {
 	for (int x = x1; x <= x2; x++) {
 		unsigned char value = 0;
-		if (!localPlayerIO()->isFogged(x, y)) {
+		if (!localPlayerIO()->isExplored(x, y)) {
+			value = 0;
+		} else if(localPlayerIO()->isFogged(x, y)) {
+			value = 205;
+		} else {
 			value = 255;
 		}
 
@@ -918,7 +918,6 @@ BoGroundRendererBase::BoGroundRendererBase()
 
 BoGroundRendererBase::~BoGroundRendererBase()
 {
- boDebug() << k_funcinfo << endl;
  mColorMapRenderers.setAutoDelete(true);
  mColorMapRenderers.clear();
  delete mFogTexture;
@@ -953,7 +952,6 @@ void BoGroundRendererBase::updateMapCache(const BosonMap* map)
  if (mCurrentMap == map) {
 	return;
  }
- boDebug() << k_funcinfo << endl;
  mCurrentGroundThemeData = 0;
  mCurrentMap = map;
  BO_CHECK_NULL_RET(mCurrentMap);
@@ -1005,7 +1003,6 @@ void BoGroundRendererBase::updateMapCache(const BosonMap* map)
  }
  mCellListBuilder->updateMapCache(mCurrentMap);
  cellTextureChanged(0, 0, map->width(), map->height());
- boDebug() << k_funcinfo << "created arrays for " << vertexCount << " vertices" << endl;
 }
 
 void BoGroundRendererBase::generateCellList(const BosonMap* map)
@@ -1058,6 +1055,12 @@ void BoGroundRendererBase::cellFogChanged(int x1, int y1, int x2, int y2)
  mFogTexture->cellChanged(x1, y1, x2, y2);
 }
 
+void BoGroundRendererBase::cellExploredChanged(int x1, int y1, int x2, int y2)
+{
+ mFogTexture->setLocalPlayerIO(localPlayerIO());
+ mFogTexture->cellChanged(x1, y1, x2, y2);
+}
+
 QString BoGroundRendererBase::debugStringForPoint(const BoVector3Fixed& pos) const
 {
  QString s;
@@ -1152,7 +1155,6 @@ BoColorMapRenderer* BoGroundRendererBase::getUpdatedColorMapRenderer(BoColorMap*
 	r->update();
 	return r;
  }
- boDebug() << k_funcinfo << "creating new colormap renderer" << endl;
  r = new BoColorMapRenderer(map);
  mColorMapRenderers.insert(map, r);
  return r;
